@@ -10,7 +10,10 @@ import (
 )
 
 // Whether to use kubectl or read kubeconfig ourselves
-const ParseKubeConfig properties.Property = "parse_kubeconfig"
+const (
+	ParseKubeConfig properties.Property = "parse_kubeconfig"
+	ContextAliases  properties.Property = "context_aliases"
+)
 
 type Kubectl struct {
 	props properties.Properties
@@ -88,9 +91,13 @@ func (k *Kubectl) doParseKubeConfig() bool {
 		if !exists {
 			continue
 		}
+
 		if context != nil {
 			k.KubeContext = *context
 		}
+
+		k.SetContextAlias()
+
 		return true
 	}
 
@@ -123,6 +130,7 @@ func (k *Kubectl) doCallKubectl() bool {
 		return false
 	}
 	k.Context = config.CurrentContext
+	k.SetContextAlias()
 	if len(config.Contexts) > 0 {
 		k.KubeContext = *config.Contexts[0].Context
 	}
@@ -137,3 +145,10 @@ func (k *Kubectl) setError(message string) {
 	k.User = message
 	k.Cluster = message
 }
+
+func (k *Kubectl) SetContextAlias() {
+	aliases := k.props.GetKeyValueMap(ContextAliases, map[string]string{})
+	if alias, exists := aliases[k.Context]; exists {
+		k.Context = alias
+	}
+}
